@@ -13,7 +13,6 @@ import (
 	"math/rand"
 	"path/filepath"
 	"sort"
-	"strings"
 	"sync/atomic"
 	"time"
 
@@ -29,6 +28,9 @@ import (
 	"github.com/syncthing/syncthing/lib/watchaggregator"
 )
 
+// scanLimiter limits the number of concurrent scans. A limit of zero means no limit.
+var scanLimiter = newByteSemaphore(0)
+
 var errWatchNotStarted = errors.New("not started")
 
 type folder struct {
@@ -285,6 +287,10 @@ func (f *folder) scanSubdirs(subDirs []string) error {
 	f.model.fmut.RUnlock()
 	mtimefs := fset.MtimeFS()
 
+	f.setState(FolderScanWaiting)
+	scanLimiter.take(1)
+	defer scanLimiter.give(1)
+
 	for i := range subDirs {
 		sub := osutil.NativeFilename(subDirs[i])
 
@@ -411,7 +417,6 @@ func (f *folder) scanSubdirs(subDirs []string) error {
 	// ignored files.
 	var toIgnore []db.FileInfoTruncated
 	ignoredParent := ""
-	pathSep := string(fs.PathSeparator)
 	for _, sub := range subDirs {
 		var iterError error
 
@@ -423,7 +428,7 @@ func (f *folder) scanSubdirs(subDirs []string) error {
 				return false
 			}
 
-			if ignoredParent != "" && !strings.HasPrefix(file.Name, ignoredParent+pathSep) {
+			if ignoredParent != "" && !fs.IsParent(file.Name, ignoredParent) {
 				for _, file := range toIgnore {
 					l.Debugln("marking file as ignored", file)
 					nf := file.ConvertToIgnoredFileInfo(f.model.id.Short())
@@ -698,11 +703,10 @@ func (f *folder) clearScanErrors(subDirs []string) {
 		return
 	}
 	filtered := f.scanErrors[:0]
-	pathSep := string(fs.PathSeparator)
 outer:
 	for _, fe := range f.scanErrors {
 		for _, sub := range subDirs {
-			if strings.HasPrefix(fe.Path, sub+pathSep) {
+			if fe.Path == sub || fs.IsParent(fe.Path, sub) {
 				continue outer
 			}
 		}
@@ -735,7 +739,7 @@ func unifySubs(dirs []string, exists func(dir string) bool) []string {
 			dirs = append(dirs[:i], dirs[i+1:]...)
 			continue
 		}
-		if dir == prev || strings.HasPrefix(dir, prev+string(fs.PathSeparator)) {
+		if dir == prev || fs.IsParent(dir, prev) {
 			dirs = append(dirs[:i], dirs[i+1:]...)
 			continue
 		}
