@@ -250,7 +250,7 @@ func (w *walker) walkAndHashFiles(ctx context.Context, toHashChan chan<- protoco
 				return skip
 			}
 			// If the parent wasn't ignored already, set this path as the "highest" ignored parent
-			if info.IsDir() && (ignoredParent == "" || !strings.HasPrefix(path, ignoredParent+string(fs.PathSeparator))) {
+			if info.IsDir() && (ignoredParent == "" || !fs.IsParent(path, ignoredParent)) {
 				ignoredParent = path
 			}
 			return nil
@@ -295,9 +295,10 @@ func (w *walker) handleItem(ctx context.Context, path string, toHashChan chan<-
 		return skip
 	}
 
+	oldPath := path
 	path, err = w.normalizePath(path, info)
 	if err != nil {
-		w.handleError(ctx, "normalizing path", path, err, finishedChan)
+		w.handleError(ctx, "normalizing path", oldPath, err, finishedChan)
 		return skip
 	}
 
